==> aly_0.1.0.orig.tar.gz: aly-0.1.0/toolbox.cpp <==
/***************************************************************************
 *   copyright       : (C) 2019-2019 by Pascal Brachet                     *
 *   https://www.xm1math.net/aly/                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "toolbox.h"
#include "geticon.h"
#include "theme.h"

ToolBox :: ToolBox(QWidget* parent/*=0*/)
    :QToolBar(parent)
{
    setFloatable(false);
    setOrientation(Qt::Horizontal);
    setMovable(false);
    setIconSize(QSize(22,22 ));
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
    setStyleSheet(Theme::viewportDarkStyleSheet);
    actionSauver = new QAction(this);
    actionSauver->setObjectName(QString::fromUtf8("actionSauver"));
    actionSauver->setIcon(getIcon(":/images/filesave.png"));


    //actionSauver->setText(tr("Save"));
    actionSauver->setToolTip(tr("Save"));
    actionSauver->setShortcut(Qt::CTRL+Qt::Key_S);


    setObjectName(QString::fromUtf8("toolBar"));
    setAllowedAreas(Qt::TopToolBarArea);

    addAction(actionSauver);

}
ToolBox :: ~ToolBox()
{
 
}

==> aly_0.2.1.orig.tar.gz: aly-0.2.1/toolbox.cpp <==
/***************************************************************************
 *   copyright       : (C) 2019-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/aly/                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#include "toolbox.h"
#include "geticon.h"
#include "theme.h"

ToolBox :: ToolBox(QWidget* parent/*=0*/)
    :QToolBar(parent)
{
    setFloatable(false);
    setOrientation(Qt::Horizontal);
    setMovable(false);
    setIconSize(QSize(22,22 ));
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
    setStyleSheet(Theme::viewportDarkStyleSheet);
    actionSauver = new QAction(this);
    actionSauver->setObjectName(QString::fromUtf8("actionSauver"));
    actionSauver->setIcon(getIcon(":/images/filesave.png"));


    //actionSauver->setText(tr("Save"));
    actionSauver->setToolTip(tr("Save"));
    actionSauver->setShortcut(Qt::CTRL | Qt::Key_S);


    setObjectName(QString::fromUtf8("toolBar"));
    setAllowedAreas(Qt::TopToolBarArea);

    addAction(actionSauver);

}
ToolBox :: ~ToolBox()
{
 
}
